@@ -35,6 +35,7 @@
 #include <fcntl.h>
 #include <math.h>
 #include <assert.h>
+#include "arts_export.h"
 
 #define arts_backend_debug(x) ;
 
@@ -272,12 +273,12 @@ public:
 		return ARTS_E_NOIMPL;
 	}
 
-	virtual int write(const mcopbyte *data, int size)
+	virtual int write(const mcopbyte * /*data*/, int /*size*/)
 	{
 		return ARTS_E_NOIMPL;
 	}
 
-	virtual int read(mcopbyte *data, int size)
+	virtual int read(mcopbyte * /*data*/, int /*size*/)
 	{
 		return ARTS_E_NOIMPL;
 	}
@@ -708,7 +709,7 @@ ArtsCApi *ArtsCApi::instance = 0;
 
 //------------------ wrappers from C to C++ class ----------------------------
 
-extern "C" int arts_backend_init()
+extern "C" ARTSC_EXPORT int arts_backend_init()
 {
 	arts_backend_debug("arts_backend_init");
 	ArtsCApi::ref();
@@ -720,21 +721,21 @@ extern "C" int arts_backend_init()
 	return rc;
 }
 
-extern "C" int arts_backend_suspend()
+extern "C" ARTSC_EXPORT int arts_backend_suspend()
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
 	arts_backend_debug("arts_backend_suspend");
 	return ArtsCApi::the()->suspend();	
 }
 
-extern "C" int arts_backend_suspended()
+extern "C" ARTSC_EXPORT int arts_backend_suspended()
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
 	arts_backend_debug("arts_backend_suspended");
 	return ArtsCApi::the()->suspended();	
 }
 
-extern "C" void arts_backend_free()
+extern "C" ARTSC_EXPORT void arts_backend_free()
 {
 	if(!ArtsCApi::the()) return;
 
@@ -743,7 +744,7 @@ extern "C" void arts_backend_free()
 	ArtsCApi::release();
 }
 
-extern "C" arts_stream_t arts_backend_play_stream(int rate, int bits, int channels, const char *name)
+extern "C" ARTSC_EXPORT arts_stream_t arts_backend_play_stream(int rate, int bits, int channels, const char *name)
 {
 	if(!ArtsCApi::the()) return 0;
 
@@ -751,7 +752,7 @@ extern "C" arts_stream_t arts_backend_play_stream(int rate, int bits, int channe
 	return ArtsCApi::the()->play_stream(rate,bits,channels,name);
 }
 
-extern "C" arts_stream_t arts_backend_record_stream(int rate, int bits, int channels, const char *name)
+extern "C" ARTSC_EXPORT arts_stream_t arts_backend_record_stream(int rate, int bits, int channels, const char *name)
 {
 	if(!ArtsCApi::the()) return 0;
 
@@ -759,7 +760,7 @@ extern "C" arts_stream_t arts_backend_record_stream(int rate, int bits, int chan
 	return ArtsCApi::the()->record_stream(rate,bits,channels,name);
 }
 
-extern "C" void arts_backend_close_stream(arts_stream_t stream)
+extern "C" ARTSC_EXPORT void arts_backend_close_stream(arts_stream_t stream)
 {
 	if(!ArtsCApi::the()) return;
 
@@ -767,7 +768,7 @@ extern "C" void arts_backend_close_stream(arts_stream_t stream)
 	ArtsCApi::the()->close_stream(stream);
 }
 
-extern "C" int arts_backend_read(arts_stream_t stream, void *buffer, int count)
+extern "C" ARTSC_EXPORT int arts_backend_read(arts_stream_t stream, void *buffer, int count)
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
 
@@ -775,7 +776,7 @@ extern "C" int arts_backend_read(arts_stream_t stream, void *buffer, int count)
 	return ArtsCApi::the()->read(stream,buffer,count);
 }
 
-extern "C" int arts_backend_write(arts_stream_t stream, const void *buffer,
+extern "C" ARTSC_EXPORT int arts_backend_write(arts_stream_t stream, const void *buffer,
 						int count)
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
@@ -784,7 +785,7 @@ extern "C" int arts_backend_write(arts_stream_t stream, const void *buffer,
 	return ArtsCApi::the()->write(stream,buffer,count);
 }
 
-extern "C" int arts_backend_stream_set(arts_stream_t stream,
+extern "C" ARTSC_EXPORT int arts_backend_stream_set(arts_stream_t stream,
 						arts_parameter_t param, int value)
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
@@ -793,7 +794,7 @@ extern "C" int arts_backend_stream_set(arts_stream_t stream,
 	return ArtsCApi::the()->stream_set(stream,param,value);
 }
 
-extern "C" int arts_backend_stream_get(arts_stream_t stream,
+extern "C" ARTSC_EXPORT int arts_backend_stream_get(arts_stream_t stream,
 						arts_parameter_t param)
 {
 	if(!ArtsCApi::the()) return ARTS_E_NOINIT;
