@@ -99,9 +99,6 @@ class ReversedDataHandle_impl : virtual public DataHandle_impl,
 	void init(DataHandle sourceHandle)
 	{
 		DataHandle_impl *impl = dynamic_cast<DataHandle_impl *>(sourceHandle._base());
-		if (!impl) {
-			return;
-		}
 		dhandle_ = impl->createReversed();
 	}
 };
