@@ -1,3 +1,3 @@
 /* this is a C++ dummy source to force c++ linkage of the examples */
 
-namespace Arts { int arts_flow_gsl_dummy = 0; };
+namespace Arts { int arts_flow_gsl_dummy = 0; }
