@@ -782,6 +782,9 @@ printf_string_upper_bound (const gchar *format,
 }
 
 static char*
+#ifdef __GNUC__
+__attribute__ ( (format (printf, 1, 0) ) )
+#endif
 arts_strdup_vprintf (const char *format, va_list args1)
 {
   gchar *buffer;
@@ -802,6 +805,9 @@ arts_strdup_vprintf (const char *format, va_list args1)
 }
 
 char*
+#ifdef __GNUC__
+__attribute__ ( (format (printf, 1, 0) ) )
+#endif
 arts_strdup_printf (const char *format, ...)
 {
   gchar *buffer;
