@@ -619,7 +619,11 @@ void Object_skel::_releaseRemote()
 	for(i=_remoteUsers.begin(); !found && i != _remoteUsers.end(); i++)
 	{
 		found = (*i) == conn;
-		if(found) _remoteUsers.erase(i);
+		if(found)
+                {
+                        _remoteUsers.erase(i);
+                        break;
+                }
 	}
 	assert(found);
 	_release();
