@@ -19,6 +19,9 @@
 
     */
 
+#ifndef SOUNDSERVERSTARTUP_IMPL_H
+#define SOUNDSERVERSTARTUP_IMPL_H
+
 #include "soundserver.h"
 
 namespace Arts {
@@ -41,3 +44,6 @@ public:
 };
 
 }
+
+#endif // SOUNDSERVERSTARTUP_IMPL_H
+
